import { useData } from './useData';
import { useState, useEffect } from 'react';
import { geoOrthographic, geoPath, geoGraticule, select, drag } from 'd3';
import { versorDrag } from './versorDrag';

export const WorldMap = ({ dim }) => {
  const { loResTopology, isLoading } = useData();
  const [topology, setTopology] = useState(null);
  const [rotation, setRotation] = useState([0, 0, 0]);
  
  useEffect(() => {
  	loResTopology && setTopology(loResTopology);
  }, [isLoading, loResTopology]);

  const projection = geoOrthographic()
    .scale(240)
    .translate([dim.width / 2, dim.height / 2])
    .rotate(rotation);
  const path = geoPath(projection);
  const graticule = geoGraticule();

  // rotate the globe (D3-drag and versorDrag functions update rotation state)
  const { dragStart, dragged, dragEnd } = versorDrag(projection, setRotation);
  
  const globe = select('g.globe');
  globe.call(
    drag()
      .on('start', dragStart)
      .on('drag', dragged)
      .on('end', dragEnd)
  );
  
  return (
    <div className="svgContainer">
      <svg
        width={dim.width}
        height={dim.height}
        viewBox={`0 0 ${dim.width} ${dim.height}`}
      >
        <g className="globe">
          <path
            className="sphere"
            d={path({ type: 'Sphere' })}
          ></path>
          <path
            className="graticule"
            d={path(graticule())}
          ></path>
        </g>
      </svg>
    </div>
  );
};
